# ReverseInvoiceRequest


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**apply_effective_date** | **date** | The date when the credit memo is applied to the invoice that will be reversed, in &#x60;yyyy-mm-dd&#x60; format. The effective date must be later than or equal to the memo date.  The default value is the date when you reverse the invoice and create the credit memo.  | [optional] 
**comment** | **str** | Comments about the reversal. The comment is used as the comment of the credit memo generated by reversing the specified invoice.  | [optional] 
**memo_date** | **date** | The date when the credit memo was created, in &#x60;yyyy-mm-dd&#x60; format. The memo date must be later than or equal to the invoice date.  The default value is the date when you reverse the invoice and create the credit memo.  | [optional] 
**reason_code** | **str** | A code identifying the reason for the transaction. The value must be an existing reason code or empty. If you do not specify a value, Zuora uses the default reason code &#x60;Invoice reversal&#x60; for the credit memo.  | [optional] 

## Example

```python
from zuora_sdk.models.reverse_invoice_request import ReverseInvoiceRequest

# TODO update the JSON string below
json = "{}"
# create an instance of ReverseInvoiceRequest from a JSON string
reverse_invoice_request_instance = ReverseInvoiceRequest.from_json(json)
# print the JSON string representation of the object
print(ReverseInvoiceRequest.to_json())

# convert the object into a dict
reverse_invoice_request_dict = reverse_invoice_request_instance.to_dict()
# create an instance of ReverseInvoiceRequest from a dict
reverse_invoice_request_from_dict = ReverseInvoiceRequest.from_dict(reverse_invoice_request_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


